@@ -618,3 +618,19 @@ class ConnectIntf:
         """
 
         _abstract()
+
+    def load_collection(self, db_name, collection_name, timeout):
+
+        _abstract()
+
+    def release_collection(self, db_name, collection_name, timeout):
+
+        _abstract()
+
+    def load_partitions(self, db_name, collection_name, timeout):
+
+        _abstract()
+
+    def release_partitions(self, db_name, collection_name, timeout):
+
+        _abstract()
