@@ -341,6 +341,8 @@ class GrpcHandler(AbsMilvus):
             LOGGER.error(status)
             raise BaseException(status.error_code, status.reason)
 
+        self.load_collection("", collection_name)
+
         # return Status(status.error_code, status.reason)
 
     @error_handler()
@@ -400,6 +402,7 @@ class GrpcHandler(AbsMilvus):
         response = rf.result()
         if response.error_code != 0:
             raise BaseException(response.error_code, response.reason)
+        self.load_partitions(db_name="", collection_name=collection_name, partition_names=[partition_tag], timeout=timeout)
         # return Status(response.status.error_code, response.status.reason)
 
     @error_handler()
