@@ -481,9 +481,32 @@ class Prepare:
 
     @classmethod
     def describe_index_progress_request(cls, collection_name, field_name):
-
         return milvus_types.DescribeIndexProgressRequest(collection_name=collection_name, field_name=field_name)
 
     @classmethod
     def get_index_state_request(cls, collection_name, field_name):
         return milvus_types.IndexStateRequest(collection_name=collection_name, field_name=field_name)
+
+    @classmethod
+
+    def load_collection(cls, db_name, collection_name):
+        return milvus_types.LoadCollectionRequest(collection_name=collection_name, db_name=db_name)
+
+    @classmethod
+    def release_collection(cls, db_name, collection_name):
+        return milvus_types.ReleaseCollectionRequest(collection_name=collection_name, db_name=db_name)
+
+    @classmethod
+    def load_partitions(cls, db_name, collection_name, partition_names):
+        return milvus_types.LoadPartitonRequest(db_name=db_name, collection_name=collection_name, partition_names= partition_names)
+
+    @classmethod
+    def release_partitions(cls, db_name, collection_name, partition_names):
+        return milvus_types.ReleasePartitionRequest(db_name=db_name, collection_name=collection_name, partition_names=partition_names)
+
+    def get_collection_stats_request(cls, collection_name):
+        return milvus_types.CollectionStatsRequest(collection_name=collection_name)
+
+    @classmethod
+    def flush_param(cls, collection_names):
+        return milvus_types.FlushRequest(collection_names=collection_names)
