@@ -406,7 +406,41 @@ class Milvus:
 
     @check_connect
     def flush(self, collection_names=None, timeout=None, **kwargs):
-        pass
+        if collection_names in (None, []):
+            with self._connection() as handler:
+                return handler.flush([], timeout, **kwargs)
+
+        if not isinstance(collection_names, list):
+            raise ParamError("Collection name array must be type of list")
+
+        if len(collection_names) <= 0:
+            raise ParamError("Collection name array is not allowed to be empty")
+
+        for name in collection_names:
+            check_pass_param(collection_name=name)
+        with self._connection() as handler:
+            return handler.flush(collection_names, timeout, **kwargs)
+
+    @check_connect
+    def get_collection_stats(self, collection_name, timeout=30, **kwargs):
+        """
+        Returns collection statistics information.
+
+        :return:
+            statistics: statistics information
+
+        :raises:
+            CollectionNotExistException(BaseException)
+            IllegalCollectionNameException(BaseException)
+
+        """
+        with self._connection() as handler:
+            stats = handler.get_collection_stats(collection_name, timeout=timeout, **kwargs)
+            result = {}
+            for stat in stats:
+                result[stat.key] = stat.value
+            return result
+
 
     @check_connect
     def create_index(self, collection_name, field_name, params, timeout=None, **kwargs):
@@ -459,3 +493,27 @@ class Milvus:
     def _cmd(self, *args, **kwargs):
         if "mode" in args or "mode" in kwargs:
             return "CPU"
+
+    @check_connect
+    def load_collection(self, db_name, collection_name, timeout=30):
+        check_pass_param(collection_name=collection_name)
+        with self._connection() as handler:
+            return handler.load_collection(db_name=db_name, collection_name=collection_name, timeout=timeout)
+
+    @check_connect
+    def release_collection(self, db_name, collection_name, timeout=30):
+        check_pass_param(collection_name=collection_name)
+        with self._connection() as handler:
+            return handler.release_collection(db_name=db_name, collection_name=collection_name, timeout=timeout)
+
+    @check_connect
+    def load_partitions(self, db_name, collection_name, partitions_names, timeout=30):
+        check_pass_param(collection_name=collection_name)
+        with self._connection() as handler:
+            return handler.load_partitions(db_name=db_name, collection_name=collection_name, partitions_names=partitions_names, timeout=timeout)
+
+    @check_connect
+    def release_partitions(self, db_name, collection_name, partitions_name, timeout=30):
+        check_pass_param(collection_name=collection_name)
+        with self._connection() as handler:
+            return handler.release_partitions(db_name=db_name, collection_name=collection_name, partitions_name=partitions_name, timeout=timeout)
